@@ -1,5 +1,5 @@
 /*
-  $Id: TimblAPI.h 9072 2011-03-23 09:20:03Z sloot $
+  $Id: TimblAPI.h 12970 2011-08-25 08:09:39Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/include/timbl/TimblAPI.h $
 
   Copyright (c) 1998 - 2011
@@ -32,7 +32,6 @@
 
 #include <string>
 #include <vector>
-#include "config.h"
 #include "StringOps.h"
 #include "Common.h"
 #include "MsgClass.h"
@@ -46,6 +45,9 @@
 
 namespace Timbl{
   
+  inline std::string Version() { return Common::Version(); };
+  inline std::string VersionName() { return Common::VersionName(); };
+  
   enum Algorithm { UNKNOWN_ALG, IB1, IB2, IGTREE, TRIBL, TRIBL2, LOO, CV };
   enum Weighting { UNKNOWN_W, UD, NW, GR, IG, X2, SV, SD };
   
