@@ -1,5 +1,5 @@
 /*
-  $Id: Instance.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: Instance.cxx 12865 2011-08-11 14:39:27Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Instance.cxx $
 
   Copyright (c) 1998 - 2011
@@ -88,6 +88,16 @@ namespace Timbl {
     distribution.clear(); 
     total_items = 0;
   }
+
+  double ValueDistribution::Confidence( const TargetValue *tv ) const {
+    VDlist::const_iterator it = distribution.begin();
+    while ( it != distribution.end() ){
+      if ( it->second->Value() == tv )
+	return it->second->Weight();
+      ++it;
+    }
+    return 0.0;
+  }
   
   void ValueDistribution::DistToEncodedString( string& DistStr ) const {
     ostringstream oss;
@@ -302,6 +312,15 @@ namespace Timbl {
     Normalize();
   }
   
+  void WValueDistribution::Normalize_2( ) {
+    VDlist::iterator it = distribution.begin();
+    while ( it != distribution.end() ){
+      it->second->SetWeight( log( it->second->Weight() + 1 ));
+      ++it;
+    }
+    Normalize();
+  }
+  
   ValueDistribution *ValueDistribution::to_VD_Copy( ) const {
     ValueDistribution *res = new ValueDistribution();
     size_t key;
@@ -537,7 +556,7 @@ namespace Timbl {
     // and signal if this ties also!
     // OR (if do_rand) take random one of the most frequents
     // signal ties too. 
-    // when do_rand, there is NEVER a tie signaled. Just pick random.
+    // BUT NOT for do_rand case! (see bug43)
     const TargetValue *best = NULL;
     tie = false;
     VDlist::const_iterator It = distribution.begin();
@@ -558,6 +577,7 @@ namespace Timbl {
 	      nof_best++;
 	  ++It;
 	}
+	//	tie = ( nof_best > 1 );
 	pick = random_number( 1, nof_best );
 	It = distribution.begin();
 	nof_best = 0;
@@ -603,7 +623,7 @@ namespace Timbl {
     // and signal if this ties also!
     // OR (if do_rand) take random one of the most frequents
     // signal ties too. 
-    // when do_rand, there is NEVER a tie signaled. Just pick random.
+    // BUT NOT for do_rand case! (see bug43)
     const TargetValue *best = NULL;
     VDlist::const_iterator It = distribution.begin();
     tie = false;
@@ -622,6 +642,7 @@ namespace Timbl {
 	      nof_best++;
 	  ++It;
 	}
+	//	tie = ( nof_best > 1 );
 	pick = random_number( 1, nof_best );
 	It = distribution.begin();
 	nof_best = 0;
