@@ -1,5 +1,5 @@
 /*
-  $Id: MBLClass.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: MBLClass.cxx 12857 2011-08-11 12:19:50Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/MBLClass.cxx $
 
   Copyright (c) 1998 - 2011
@@ -181,8 +181,8 @@ namespace Timbl {
 	Warning( "SetOption '" + line + "' failed.\nOption unknown" );
 	break;
       case Opt_Ill_Val:
-	Warning( "SetOption '" + line + 
-		 "' failed.\nillegal value for this option" );
+	Error( "SetOption '" + line + 
+	       "' failed.\nIllegal value for this option" );
 	break;
       }
     }
@@ -1416,10 +1416,8 @@ namespace Timbl {
       }
     }
     // Give a warning for singular features, except when it's
-    // a result of a forced recalculation or when the input format is
-    // Sparse ??
-    if ( realy_first &&
-	 ( input_format != Sparse && input_format != SparseBin ) ){
+    // a result of a forced recalculation 
+    if ( realy_first ){
       bool first = true;
       ostringstream ostr1;
       ostringstream ostr2;
