@@ -1,5 +1,5 @@
 /*
-  $Id: Timbl.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: Timbl.cxx 12969 2011-08-24 14:00:22Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/Timbl.cxx $
 
   Copyright (c) 1998 - 2011
@@ -39,6 +39,7 @@
 #include <ctime>
 #include <cctype>
 
+#include "config.h"
 #include "timbl/TimblAPI.h"
 
 using namespace std;
@@ -193,9 +194,14 @@ inline void usage_full(void){
   cerr << "  You may combine levels using '+' e.g. +v p+db or -v o+di"
        << endl;
   cerr << "-G        : normalize distibutions (+vdb option only)" << endl
-       << "    O     : normalize between 0 and 1" << endl
-       << "    1:<f> : add f to all possible targets" << endl
-       << "            then normalize between 0 and 1 (default f=1.0)" << endl;
+       << "    Probability    : normalize between 0 and 1" << endl
+       << "             O     : does the same " << endl
+       << "    addFactor:<f>  : add f to all possible targets" << endl
+       << "                     then normalize between 0 and 1 (default f=1.0)" << endl
+       << "             1:<f> : does the same" << endl
+       << "    logProbability : Add 1 to the target Weight, take the 10Log and" << endl
+       << "                     then normalize between 0 and 1 (default f=1.0)" << endl
+       << "             2     : does the same" << endl;
   cerr << "-W f      : calculate and save all Weights in file 'f'" << endl;
   cerr << "+% or -%  : do or don't save test result (%) to file" << endl;
   cerr << "-o s      : use s as output filename" << endl;
