@@ -1,5 +1,5 @@
 /*
-  $Id: TimblExperiment.cxx 9072 2011-03-23 09:20:03Z sloot $
+  $Id: TimblExperiment.cxx 12767 2011-08-01 09:52:00Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/Timbl6/src/TimblExperiment.cxx $
 
   Copyright (c) 1998 - 2011
@@ -162,16 +162,25 @@ namespace Timbl {
   }
   
   void resultStore::normalize() {
-    switch ( norm ){
-    case probabilityNorm:
-      dist->Normalize();
-      break;
-    case addFactorNorm:
-      dist->Normalize_1( factor, targets );
-      break;
-    default:
-      break;
+    if ( dist ){
+      switch ( norm ){
+      case noNorm:
+	break;
+      case probabilityNorm:
+	dist->Normalize();
+	break;
+      case addFactorNorm:
+	dist->Normalize_1( factor, targets );
+	break;
+      case logProbNorm:
+	dist->Normalize_2();
+	break;
+      default:
+	throw runtime_error( "unimplemented case " + toString(norm) );
+	break;
+      }
     }
+    // silently do nothing when dist == 0;
   }
 
   void TimblExperiment::normalizeResult(){
@@ -397,38 +406,43 @@ namespace Timbl {
 		chopped_to_instance( LearnWords );
 		// Progress update.
 		//
-		if (( stats.dataLines() % Progress() ) == 0)
-		  time_stamp( "Examining: ", stats.dataLines() );
-		  found = false;
-		  while ( !found && 
-			  nextLine( datafile, Buffer ) ){
-		    found = chopLine( Buffer );
-		    if ( !found ){
-		      Warning( "datafile, skipped line #" + 
-			       toString<int>( stats.totalLines() ) +
-			       "\n" + Buffer );
-		    }
+		if ( !Verbosity(SILENT) ){
+		  if (( stats.dataLines() % Progress() ) == 0)
+		    time_stamp( "Examining: ", stats.dataLines() );
+		}
+		found = false;
+		while ( !found && 
+			nextLine( datafile, Buffer ) ){
+		  found = chopLine( Buffer );
+		  if ( !found ){
+		    Warning( "datafile, skipped line #" + 
+			     toString<int>( stats.totalLines() ) +
+			     "\n" + Buffer );
 		  }
-		  go_on = found;
+		}
+		go_on = found;
 	      }
 	      if ( stats.dataLines() < 1 ){
 		Error( "no useful data in: " + FileName );
 	      }
 	      else {
-		time_stamp( "Finished:  ", stats.totalLines() );
-		time_stamp( "Calculating Entropy " );
-		if ( Verbosity(FEAT_W) && !Verbosity(SILENT) ){
-		  *mylog << "Lines of data     : " 
-			 << stats.dataLines() << endl;
-		  if ( stats.skippedLines() != 0 )
-		    *mylog << "SkippedLines      : "
-			   << stats.skippedLines() << endl;
-		  LearningInfo( *mylog );
+		if ( !Verbosity(SILENT) ){
+		  time_stamp( "Finished:  ", stats.totalLines() );
+		  time_stamp( "Calculating Entropy " );
+		  if ( Verbosity(FEAT_W) ){
+		    *mylog << "Lines of data     : " 
+			   << stats.dataLines() << endl;
+		    if ( stats.skippedLines() != 0 )
+		      *mylog << "SkippedLines      : "
+			     << stats.skippedLines() << endl;
+		    LearningInfo( *mylog );
+		  }
 		}
 		else
 		  calculate_fv_entropy( false );
 		prepT.stop();
-		Info( "Preparation took " + prepT.toString() );
+		if ( !Verbosity(SILENT) )
+		  Info( "Preparation took " + prepT.toString() );
 		if ( warnOnSingleTarget && Targets->EffectiveValues() <=1 ){
 		  Warning( "Training file contains only 1 class." );
 		}
@@ -589,7 +603,9 @@ namespace Timbl {
 	  }
 	}
       }
-      time_stamp( "Finished:  ", stats.dataLines() );
+      if ( !Verbosity(SILENT) ){
+	time_stamp( "Finished:  ", stats.dataLines() );
+      }
       learnT.stop();
       // cerr << "Endresult " << endl;
       // cerr << InstanceBase << endl;
@@ -676,9 +692,9 @@ namespace Timbl {
   }
   
   /*
-    Expand  an Instance Base (IB1 only)
+    Expand  an Instance Base
   */
-  bool IB1_Experiment::Expand( const string& FileName ){
+  bool TimblExperiment::Expand( const string& FileName ){
     bool result = true;
     if ( ExpInvalid() ){
       result = false;
@@ -1174,7 +1190,9 @@ namespace Timbl {
 	      go_on = found;
 	    }
 	  }
+	  if ( !Verbosity(SILENT) ){
 	  time_stamp( "Finished:  ", stats.dataLines() );
+	  }
 	  learnT.stop();
 	  if ( !Verbosity(SILENT) ){
 	    IBInfo( *mylog );
